from flask_admin import AdminIndexView, expose
from wtforms import validators, PasswordField, Form, EmailField
from flask_login import current_user, logout_user, login_user
from flask_babel import gettext
from mgdpr.extensions import db
from mgdpr.models.mgdpr import User
from flask import redirect, url_for, request


# Define login and registration forms (for flask-login)
class LoginForm(Form):
    email = EmailField(validators=[validators.InputRequired()])
    password = PasswordField(validators=[validators.InputRequired()])

    def __init__(self, *args, **kwargs):
        Form.__init__(self, *args, **kwargs)
        self.user = None

    def validate(self) -> bool:
        rv = Form.validate(self)
        if not rv:
            return False
        user = db.session.query(User).filter(User.email == self.email.data).first()
        # email and password found and match
        if user is None:
            self.email.errors.append(gettext('Email was not found.'))
            return False

        if user.check_password(self.password.data) is False:
            self.password.errors.append(gettext('Wrong password.'))
            return False

        self.user = user
        return True


class AdminHome(AdminIndexView):
    @expose('/')
    def index(self):
        if not current_user.is_authenticated:
            return redirect(url_for('.login_view'))
        return super(AdminHome, self).index()

    @expose('/login/', methods=('GET', 'POST'))
    def login_view(self):
        # handle user login
        form = LoginForm(request.form)
        if request.method == 'POST' and form.validate():
            login_user(form.user, remember=True)

        if current_user.is_authenticated:
            return redirect(url_for('.index'))
        self._template_args['form'] = form
        return super(AdminHome, self).index()

    @expose('/logout/')
    def logout_view(self):
        logout_user()
        return redirect(url_for('.index'))
