from flask_babel import gettext
from mgdpr.admin.base import AdminModelView
from mgdpr.extensions import db
from mgdpr.models.mgdpr import User
from wtforms import validators, PasswordField


# Customized User model admin
class UserAdmin(AdminModelView):
    # Visible columns in the list view
    column_exclude_list = ('password', )

    form_excluded_columns = ('password', 'created', 'updated',)

    # List of columns that can be sorted. For 'user' column, use User.username as
    # a column.
    #column_sortable_list = ('title', ('user', 'user.username'), 'date')

    # Rename 'title' columns to 'Post Title' in list view
    #column_labels = dict(title='Post Title')

    #column_searchable_list = ('title', User.username, 'tags.name')

    column_filters = (
        'updated',
        'created',
        'first_name',
        'last_name',
        'email'
    )

    # Pass arguments to WTForms. In this case, change label for text field to
    # be 'Big Text' and add required() validator.
    #form_args = dict(
    #                text=dict(label='Big Text', validators=[validators.required()])
    #            )
    """
    form_ajax_refs = {
        'user': {
            'fields': (User.username, User.email)
        },
        'tags': {
            'fields': (Tag.name,)
        }
    }
    """

    def get_edit_form(self):
        form_class = super(UserAdmin, self).get_edit_form()
        form_class.password2 = PasswordField('New Password', [validators.Optional(), validators.Length(min=5, max=35)])
        form_class.password2_again = PasswordField('New Password again')
        return form_class

    def get_create_form(self):
        form_class = super(UserAdmin, self).get_create_form()
        form_class.password2 = PasswordField('Password', [validators.DataRequired(), validators.Length(min=5, max=35)])
        form_class.password2_again = PasswordField('Password again')
        return form_class

    def validate_form(self, form):
        """ Custom validation code that checks dates """
        if form.password2.data:
            if form.password2.data != form.password2_again.data:
                errors = list(form.password2.errors)
                errors.append(gettext('Passwords do not match.'))
                form.password2.errors = tuple(errors)
                return False
        return super(UserAdmin, self).validate_form(form)

    # This callback executes when the user saves changes to a newly-created or edited User -- before the changes are
    # committed to the database.
    def on_model_change(self, form, model, is_created):
        # If the password field isn't blank...
        if len(model.password2):
            # ... then encrypt the new password prior to storing it in the database. If the password field is blank,
            # the existing password in the database will be retained.
            model.set_password(model.password2)

    def __init__(self):
        # Just call parent class with predefined model.
        super(UserAdmin, self).__init__(User, db.session)
