# -*- coding: utf-8 -*-

"""Flask and other extensions instantiated here.

To avoid circular imports with views and create_app(), extensions are instantiated here. They will be initialized
(calling init_app()) in application.py.
"""
import os
from logging import getLogger
import mgdpr as app_root
from flask_sqlalchemy import SQLAlchemy
from sqlalchemy.event import listens_for
from sqlalchemy.pool import Pool
from flask_admin import Admin
from flask_login import LoginManager
from flask_babel import Babel
from flask_celery import Celery
from flask_migrate import Migrate
from flask_mail import Mail

LOG = getLogger(__name__)
APP_ROOT_FOLDER = os.path.abspath(os.path.dirname(app_root.__file__))
MIGRATE_ROOT_FOLDER = os.path.abspath(os.path.join(APP_ROOT_FOLDER, 'migrations'))


db = SQLAlchemy()
babel = Babel()
celery = Celery()
mail = Mail()
login_manager = LoginManager()
admin = Admin(base_template='my_master.html')
migrate = Migrate(directory=MIGRATE_ROOT_FOLDER)
