# -*- coding: utf-8 -*-
import json
import uuid
from flask import jsonify, request
from mgdpr.blueprints import api_index
from mgdpr.tasks.mgdpr import send_email
from mgdpr.models.mgdpr import Email, EmailTranslation, Request, Locale
from mgdpr.extensions import db

__author__ = "Adam Schubert"
__date__ = "$26.7.2017 19:33:05$"


@api_index.route('/authorize/<string:name>', methods=['POST'])
def authorize(name: str):
    data = request.get_json()
    access_token = data.get('access_token')
    if not access_token:
        return jsonify({'message': 'Token was not provided'}), 400

    locale = data.get('locale')
    if not locale:
        return jsonify({'message': 'Locale was not provided'}), 400

    email = data.get('email')
    if not email:
        return jsonify({'message': 'Email was not provided'}), 400

    hook_url = data.get('hook_url')
    if not hook_url:
        return jsonify({'message': 'Hook URL was not provided'}), 400

    found_locale = Locale.query.filter_by(code=locale).first()
    if not found_locale:
        return jsonify({'message': 'Locale not found'}), 400

    found_email = Email.query.join(EmailTranslation).join(Locale).filter(Email.name == name, Locale.code == found_locale.code).first()
    if not found_email:
        return jsonify({'message': 'Email not found'}), 404

    try:
        access_token_uuid = uuid.UUID(access_token)
    except ValueError as e:
        return jsonify({'message': str(e)}), 400

    if found_email.access_token != access_token_uuid:
        return jsonify({'message': 'Provided token was incorrect'}), 400

    new_request = Request()
    new_request.email = found_email
    new_request.locale = found_locale
    new_request.hook_url = hook_url
    new_request.is_agreement = False
    new_request.payload = json.dumps(data.get('payload', {}))
    new_request.redirect_url = data.get('redirect_url', None)
    new_request.target_email = email
    db.session.add(new_request)
    db.session.commit()

    task = send_email.delay(new_request.id)
    return jsonify({'message': 'Email task started', 'task-uuid': task.id, 'uuid': new_request.uuid}), 200
