# -*- coding: utf-8 -*-
import re
import os
from flask import jsonify, request, render_template_string, redirect
from mgdpr.blueprints import landing_page_index
from mgdpr.tasks.mgdpr import process_land
from mgdpr.tools.helpers import update_url_params
from mgdpr.models.mgdpr import LandingPage, LandingPageTranslation, Request, Locale
from mgdpr.extensions import db


__author__ = "Adam Schubert"
__date__ = "$26.7.2017 19:33:05$"


@landing_page_index.route('/<int:landing_page_id>', methods=['GET'])
def show_landing_page(landing_page_id: str):
    request_uuid = request.args.get('uuid')
    if not request_uuid:
        return jsonify({'message': 'UUID was not provided'}), 400

    request_found = Request.query.filter_by(uuid=request_uuid).first()
    if not request_found:
        return jsonify({'message': 'Request was not found'}), 400

    landing_page, landing_page_translation = db.session.query(LandingPage, LandingPageTranslation)\
        .join(LandingPageTranslation)\
        .join(Locale)\
        .filter(LandingPage.id == landing_page_id, Locale.id == request_found.locale.id).first()
    if not landing_page:
        return jsonify({'message': 'Landing page was not found'}), 400

    request_found.landing_page = landing_page

    db.session.add(request_found)
    db.session.commit()

    task = process_land.delay(request_found.id)

    if request_found.redirect_url:
        return redirect(update_url_params(request_found.redirect_url, {
            'success': int(landing_page.is_success),
            'task_id': task.id
        }))

    # Process template
    template = landing_page_translation.text.replace('{pagetitle}', landing_page_translation.title)\
        .replace('{pagemetadescription}', landing_page_translation.meta_description)

    template = re.sub(
        r"{filelink=(\S+)}",
        lambda m: "{{{{url_for('api_upload.get_file', filename='{}', _external=True)}}}}".format(
            os.path.join(m.group(1))
        ),
        template
    )

    return render_template_string(
        template,
        task=task,
        request_found=request_found
    )
